@@ -1,4 +1,5 @@
 use crate::internal::*;
+use crate::ops::cnn::pools::pulsify_pooled_input;
 use tract_core::ops::cnn::ConvUnary;
 
 register_all!(ConvUnary: pulsify);
@@ -10,15 +11,19 @@ fn pulsify(
     target: &mut PulsedModel,
     mapping: &HashMap<OutletId, OutletId>,
     _pulse: usize,
-) -> TractResult<TVec<OutletId>> {
+) -> TractResult<Option<TVec<OutletId>>> {
     fn zero<D: Datum>() -> Tensor {
         tensor0(D::default())
     }
     let fact = target.outlet_fact(mapping[&node.inputs[0]])?;
     let zero = dispatch_numbers!(zero(fact.datum_type)());
-    let (wire, pool_spec) =
-        super::pools::pulsify(&op.pool_spec, source, node, target, mapping, Some(zero))?;
-    target.wire_node(&node.name, ConvUnary { pool_spec, ..op.clone() }, &[wire])
+    if let Some((wire, pool_spec)) =
+        pulsify_pooled_input(&op.pool_spec, source, node, target, mapping, Some(zero))?
+    {
+        Ok(Some(target.wire_node(&node.name, ConvUnary { pool_spec, ..op.clone() }, &[wire])?))
+    } else {
+        Ok(None)
+    }
 }
 
 impl PulsedOp for ConvUnary {
